<?php
$this->js_css->parse_js('rtgrid/js/jquery.cookie.js');
$this->js_css->parse_js('rtgrid/js/clone.js');
?>
{form_open}
<ul id="myTab" class="nav nav-tabs">
    {tabs_control}
    <li {active}><a href="#{id}" data-toggle="tab">{name}</a></li>
    {/tabs_control}
</ul>
<div id="myTabContent" class="tab-content">
    <?php if (!empty($message) || $this->session->flashdata('rtgrid_edit_flash_message')) : ?>
        <?= $message.$this->session->flashdata('rtgrid_edit_flash_message') ?>
    <?php endif; ?>
    {tabs}
    <div class="tab-pane {active}" id="{id}">
        {data}
    </div>
    {/tabs}
</div>
<div class="form-actions">
    {actions}
    {action}
    {/actions}
</div>
{form_close}