.grid_tooltip_block{
    float: left;
    margin-right: 5px;
}
.control-label .grid_tooltip_block{
    float: right;
    margin: 0 0 0 5px;
    text-align: left;
}
.grid_tooltip_block .grid_tooltip{
    float: left;
    cursor: pointer;
}